==> igniteui-react-charts-18.7.0-beta.2.tgz: package/esm5/lib/Stacked100DataPreparer.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "igniteui-react-core";
/**
 * @hidden
 */
var Stacked100DataPreparer = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100DataPreparer, _super);
    function Stacked100DataPreparer() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Stacked100DataPreparer.a = function (a) {
        if (a.dl == null) {
            return;
        }
        var b = Number.POSITIVE_INFINITY;
        var c = Number.NEGATIVE_INFINITY;
        for (var d = 0; d < a.dl.count; d++) {
            var e = Math.abs(a.aab[d]) + a.aaa[d];
            if (e == 0) {
                b = Math.min(b, 0);
                c = Math.max(c, 0);
                continue;
            }
            b = Math.min(b, a.aab[d] / e * 100);
            c = Math.max(c, a.aaa[d] / e * 100);
        }
        a.aat = b;
        a.aas = c;
    };
    Stacked100DataPreparer.$t = markType(Stacked100DataPreparer, 'Stacked100DataPreparer');
    return Stacked100DataPreparer;
}(Base));
export { Stacked100DataPreparer };

==> igniteui-react-charts-18.7.5-beta.2.tgz: package/esm5/lib/Stacked100DataPreparer.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "igniteui-react-core";
/**
 * @hidden
 */
var Stacked100DataPreparer = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100DataPreparer, _super);
    function Stacked100DataPreparer() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Stacked100DataPreparer.a = function (a) {
        if (a.dn == null) {
            return;
        }
        var b = Number.POSITIVE_INFINITY;
        var c = Number.NEGATIVE_INFINITY;
        for (var d = 0; d < a.dn.count; d++) {
            var e = Math.abs(a.aat[d]) + a.aas[d];
            if (e == 0) {
                b = Math.min(b, 0);
                c = Math.max(c, 0);
                continue;
            }
            b = Math.min(b, a.aat[d] / e * 100);
            c = Math.max(c, a.aas[d] / e * 100);
        }
        a.abc = b;
        a.abb = c;
    };
    Stacked100DataPreparer.$t = markType(Stacked100DataPreparer, 'Stacked100DataPreparer');
    return Stacked100DataPreparer;
}(Base));
export { Stacked100DataPreparer };
